OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Txertatutako mezua %s",
    "Important mail" : "Posta garrantzitsua",
    "No message found yet" : "Ez da mezurik aurkitu oraindik.",
    "Set up an account" : "Konfiguratu kontu bat",
    "Unread mail" : "Irakurri gabeko posta",
    "Important" : "Garrantzitsua",
    "Work" : "Lana",
    "Personal" : "Pertsonala",
    "To Do" : "Egiteke",
    "Later" : "Beranduago",
    "Mail" : "Posta",
    "You are reaching your mailbox quota limit for {account_email}" : "{account_email} konturako postontziaren kuota-mugara heltzen ari zara",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Zure postontziaren biltegiaren {percentage} erabiltzen ari zara une honetan. Mesedez, egin ezazu lekua behar ez dituzun postak ezabatuz.",
    "Mails" : "Posta",
    "💌 A mail app for Nextcloud" : "💌 Posta elektroniko zerbitzu bat Nextcloudekin",
    "Your session has expired. The page will be reloaded." : "Zure saioa iraungi da. Orria berriro kargatuko da.",
    "Drafts are saved in:" : "Zirriborroak hemen gordetzen dira:",
    "Sent messages are saved in:" : "Bidalitako mezuak hemen gordetzen dira:",
    "Deleted messages are moved in:" : "Ezabatutako mezuak hona mugitzen dira:",
    "Archived messages are moved in:" : "Artxibatutako mezuak hona mugitzen dira:",
    "Snoozed messages are moved in:" : "Beste aldi baterako utzitako mezuak hona mugitzen dira:",
    "Junk messages are saved in:" : "Zabor mezuak hemen gordetzen dira:",
    "Auto" : "Auto",
    "Name" : "Izena",
    "Mail address" : "Helbide elektronikoa",
    "name@example.org" : "izena@adibidea.org",
    "Please enter an email of the format name@example.com" : "Mesedez, sartu name@example.com formatuko mezu elektroniko bat",
    "Password" : "Pasahitza",
    "Manual" : "Eskuz",
    "IMAP Settings" : "IMAP ezarpenak",
    "IMAP Host" : "IMAP ostalaria",
    "IMAP Security" : "IMAP segurtasuna",
    "None" : "Bat ere ez",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP ataka",
    "IMAP User" : "IMAP erabiltzailea",
    "IMAP Password" : "IMAP pasahitza",
    "SMTP Settings" : "SMTP ezarpenak",
    "SMTP Host" : "SMTP ostalaria",
    "SMTP Security" : "SMTP segurtasuna",
    "SMTP Port" : "SMTP ataka",
    "SMTP User" : "SMTP erabiltzailea",
    "SMTP Password" : "SMTP pasahitza",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Google-ko kontuak aplikazio honekin funtziona dezan, Google-n bi faktoreko autentifikazioa gaitu eta aplikazioaren pasahitza sortu behar duzu.",
    "Connecting" : "Konektatzen",
    "Reconnect Google account" : "Konektatu berriro Google kontua",
    "Sign in with Google" : "Hasi saioa Google-rekin",
    "Save" : "Gorde",
    "Connect" : "Konektatu",
    "Looking up configuration" : "Konfigurazioa begiratzen",
    "Checking mail host connectivity" : "Mail ostalariaren konektibitatea egiaztatzen",
    "Configuration discovery failed. Please use the manual settings" : "Konfigurazioaren ezagutzak huts egin du. Erabili eskuzko ezarpenak mesedez",
    "Password required" : "Pasahitza beharrezkoa da",
    "Testing authentication" : "Autentifikazioa probatzen",
    "Awaiting user consent" : "Erabiltzailearen onarpenaren zain",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Kontua sortu da. Mesedez, jarraitu popup-aren jarraibideak zure Google kontua estekatzeko",
    "Loading account" : "Kontua kargatzen",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Kontua eguneratu da. Mesedez, jarraitu popup-aren jarraibideak zure Google kontua berriro konektatzeko",
    "Account updated" : "Kontua eguneratu da",
    "IMAP server is not reachable" : "IMAP zerbitzaria ezin da atzitu",
    "SMTP server is not reachable" : "SMTP zerbitzaria ezin da atzitu",
    "IMAP username or password is wrong" : "IMAP erabiltzaile edo pasahitza txarto dago",
    "SMTP username or password is wrong" : "SMTP erabiltzaile edo pasahitza txarto dago",
    "IMAP connection failed" : "IMAP konexioak huts egin du",
    "SMTP connection failed" : "SMTP konexioak huts egin du",
    "Authorization pop-up closed" : "Baimenaren pop-up itxi da",
    "There was an error while setting up your account" : "Errore bat gertatu da zure kontua konfiguratzean",
    "Account settings" : "Kontuaren ezarpenak",
    "Aliases" : "Aliasak",
    "Alias to S/MIME certificate mapping" : "S/MIME ziurtagiriaren esleipenerako aliasa",
    "Signature" : "Sinadura",
    "A signature is added to the text of new messages and replies." : "Sinadura bat gehitzen zaio mezu berri eta erantzunen testuari.",
    "Writing mode" : "Editatzeko aukera gaituta",
    "Preferred writing mode for new messages and replies." : "Hobetsitako idazteko modua, mezu berri eta erantzunak idazteko.",
    "Default folders" : "Lehenetsitako karpetak",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Zirriborro, bidalitako, ezabatutako, artxibatutako eta zabor mezuentzako erabilitako karpeta.",
    "Automatic trash deletion" : "Zaborraren ezabatze automatikoa",
    "Autoresponder" : "Autoerantzulea",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Sarrerako mezuei erantzun automatikoa. Norbaitek hainbat mezu bidaltzen badizu, erantzun automatizatu hau gehienez 4 egunean behin bidaliko da.",
    "Please connect to a sieve server first." : "Konektatu sieve zerbitzari batera lehenik mesedez.",
    "Sieve filter rules" : "Sieve iragazketa arauak",
    "Trusted senders" : "Bidaltzaile fidagarriak",
    "Mail server" : "Posta-zerbitzaria",
    "Sieve filter server" : "Sieve iragazketa zerbitzaria",
    "Update alias" : "Eguneratu aliasa",
    "Rename alias" : "Aliasa berrizendatu",
    "Show update alias form" : "Erakutsi alias inprimakiaren eguneratzea",
    "Delete alias" : "Ezabatu aliasa",
    "Go back" : "Egin atzera",
    "Change name" : "Aldatu izena",
    "Email address" : "Helbide elektronikoa",
    "Add alias" : "Gehitu aliasa",
    "Create alias" : "Sortu aliasa",
    "Cancel" : "Utzi",
    "Add mail account" : "Gehitu posta-kontua",
    "Use Gravatar and favicon avatars" : "Erabili Gravatar eta favicon avatarrak",
    "Register as application for mail links" : "Erregistratu posta-estekentzako aplikazio bezala",
    "Show keyboard shortcuts" : "Erakutsi teklatuaren lasterbideak",
    "Manage S/MIME certificates" : "Kudeatu S/MIME ziurtagiriak",
    "Newest" : "Berrienak",
    "Oldest" : "Zaharrenak",
    "Looking for a way to encrypt your emails?" : "Zure mezu elektronikoak enkriptatzeko modu bat bilatzen ari zara?",
    "Install Mailvelope browser extension here" : "Instalatu Mailvelope arakatzailearen luzapena hemen",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
    "Put my text to the bottom of a reply instead of on top of it." : "Jarri nire testua erantzunaren behealdean, goian jarri beharrean.",
    "Automatically classify importance of new email" : "E-posta berrien garrantzia automatikoki klasifikatu",
    "Could not update preference" : "Ezin izan da hobespena eguneratu",
    "Select an alias" : "Hautatu alias bat",
    "Update Certificate" : "Eguneratu ziurtagiria",
    "No certificate" : "Ziurtagiririk ez",
    "Certificate updated" : "Ziurtagiria eguneratu da",
    "Could not update certificate" : "Ezin izan da ziurtagiria eguneratu",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - baliozkoa {expiryDate} arte",
    "From" : "Nork",
    "Select account" : "Hautatu kontua",
    "To" : "Nori",
    "Contact or email address …" : "Kontaktua edo posta helbidea…",
    "Toggle recipients list mode" : "Aldatu hartzaileen zerrenda modua",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "No contacts found." : "Ez da kontakturik aurkitu.",
    "Subject" : "Gaia",
    "Subject …" : "Gaia…",
    "This message came from a noreply address so your reply will probably not be read." : "Mezu hau noreply helbide batetik dator, beraz, ziur aski, zure erantzuna ez dute irakurriko.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Hartzaile hauek ez dute S/MIME ziurtagiririk: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : " \nHartzaile hauek ez dute PGP gakorik: {recipients}.",
    "Write message …" : "Idatzi mezua...",
    "Saving draft …" : "Zirriborroa gordetzen...",
    "Error saving draft" : "Errore bat gertatu da zirriborroa gordetzean",
    "Draft saved" : "Zirriborroa gorde egin da",
    "Save draft" : "Gorde zirriborroa",
    "Discard & close draft" : "Baztertu eta itxi zirriborroa",
    "Upload attachment" : "Igo eranskina",
    "Add attachment from Files" : "Gehitu eranskina Fitxategiak-etik",
    "Smart picker" : "Hautatzaile adimenduna",
    "Send later" : "Bidali geroago",
    "Enable formatting" : "Gaitu formateatzea",
    "Disable formatting" : "Desgaitu formateatzea",
    "Request a read receipt" : "Eskatu irakurriagiria",
    "Sign message with S/MIME" : "Sinatu mezua S/MIME-rekin",
    "Encrypt message with S/MIME" : "Enkriptatu mezua S/MIME-rekin",
    "Encrypt message with Mailvelope" : "Zifratu mezua Mailvelopekin",
    "Send now" : "Bidali orain",
    "Tomorrow morning" : "Bihar goizean",
    "Tomorrow afternoon" : "Bihar arratsaldean",
    "Monday morning" : "Astelehen goizean",
    "Custom date and time" : "Data eta ordu pertsonalizatuak",
    "Enter a date" : "Sartu data bat",
    "Add share link from {productName} Files" : "Gehitu partekatze esteka {productName} Fitxategiak-etik",
    "Encrypt with S/MIME and send later" : "Enkriptatu S/MIME-rekin eta bidali geroago",
    "Encrypt with S/MIME and send" : "Enkriptatu S/MIME-rekin eta bidali",
    "Encrypt with Mailvelope and send later" : "Enkriptatu Mailvelope-rekin eta bidali geroago",
    "Encrypt with Mailvelope and send" : "Enkriptatu Mailvelope-rekin eta bidali",
    "Send" : "Bidali",
    "Message {id} could not be found" : "Ezin izan da {id} mezua aurkitu",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "S/MIME-rekin sinatu edo enkriptatu hautatu da, baina ez dugu hautatutako aliasaren ziurtagiririk. Mezua ez da sinatuko edo enkriptatuko.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Lehendik dagoen edozein formatua (adibidez, lodia, etzana, azpimarra edo lerroan dauden irudiak) kenduko da.",
    "Turn off formatting" : "Itzali formateatzea",
    "Turn off and remove formatting" : "Itzali eta kendu formateatzea",
    "Keep formatting" : "Mantendu formateatzea",
    "Choose a file to add as attachment" : "Aukeratu fitxategia eranskin gisa gehitzeko",
    "Choose a file to share as a link" : "Aukeratu fitxategi bat esteka bezala partekatzeko",
    "_{count} attachment_::_{count} attachments_" : ["Eranskin {count}","{count} eranskin"],
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Eranskinek baimendutako {size} -ko eranskin tamaina gainditzen du. Partekatu fitxategia esteka bidez horren ordez.","Eranskinek baimendutako {size} -ko eranskin tamaina gainditzen du. Partekatu fitxategia esteka bidez horren ordez."],
    "Expand composer" : "Hedatu egilea",
    "Close composer" : "Itxi egilea",
    "Untitled message" : "Izenik gabeko mezua",
    "Confirm" : "Berretsi",
    "Plain text" : "Testu arrunta",
    "Rich text" : "Testu aberastua",
    "No messages in this mailbox" : "Mezurik ez postontzi honetan",
    "No messages" : "Mezurik ez",
    "Draft: " : "Zirriborroa: ",
    "Encrypted message" : "Zifratutako mezua",
    "This message is unread" : "Mezu hau irakurri gabe dago",
    "Unfavorite" : "Kendu gogokoetatik",
    "Favorite" : "Egin gogoko",
    "Unread" : "Irakurri gabe",
    "Read" : "Irakurri",
    "Unimportant" : "Garrantzi gabekoa",
    "Mark not spam" : "Markatu ez spam gisa",
    "Mark as spam" : "Markatu spam bezala",
    "Unselect" : "Desautatu",
    "Select" : "Hautatu",
    "Edit tags" : "Editatu etiketak",
    "Snooze" : "Beste aldi baterako utzi",
    "Move thread" : "Mugitu haria",
    "Archive thread" : "Artxibatu haria",
    "Delete thread" : "Ezabatu haria",
    "More actions" : "Ekintza gehiago",
    "Back" : "Atzera",
    "Edit as new message" : "Aldatu mezu berri gisa",
    "Create event" : "Sortu gertaera",
    "Create task" : "Sortu zeregina",
    "Download message" : "Deskargatu mezua",
    "Blind copy recipients only" : "Kopia itsuen jasotzaileek besterik ez",
    "No subject" : "Gairik ez",
    "Set reminder for later today" : "Ezarri abisua gaur beranduagorako",
    "Set reminder for tomorrow" : "Ezarri abisua biharko",
    "Set reminder for this weekend" : "Ezarri abisua asteburu honetarako",
    "Set reminder for next week" : "Ezarri abisua hurrengo asterako",
    "No trash mailbox configured" : "Ez da zakarrontzirik konfiguratu",
    "Could not delete message" : "Ezin izan da mezua ezabatu",
    "Could not archive message" : "Ezin izan da mezua artxibatu",
    "Forward" : "Birbidali",
    "Load more" : "Kargatu gehiago",
    "_Mark {number} unread_::_Mark {number} unread_" : ["Markatu {number} irakurri gabe bezala","Markatu {number} irakurri gabe bezala"],
    "_Mark {number} read_::_Mark {number} read_" : [" 100% match \nMarkatu {number} irakurrita bezala","Markatu {number} irakurrita bezala"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Markatu {number} garrantzizko","Markatu {number} garrantzizko"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Markatu {number} garrantzi gabe","Markatu {number} garrantzi gabe"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Kendu gogokoetatik {number}","Kendu gogokoetatik  {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Gogokoa {number}","Gogokoa {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Desautatu {number}","Desautatu {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Mugitu hari {number}","Mugitu {number} hari"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Birbidali {zenbakia} eranskin bezala","Birbidali {zenbakia} eranskin bezala"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["Ezabatu hari {number}","Ezabatu {number} hari"],
    "Report this bug" : "Eman errore honen berri",
    "All day" : "Egun osoa",
    "Create" : "Sortu",
    "Event created" : "Sortu da gertaera",
    "Could not create event" : "Ezin izan da gertaera sortu",
    "You accepted this invitation" : "Gonbidapen hau onartu duzu",
    "You tentatively accepted this invitation" : "Gonbidapen hau behin-behinean onartu duzu",
    "You declined this invitation" : "Gonbidapen hau baztertu duzu",
    "You already reacted to this invitation" : "Gonbidapen honi buruz erreakzionatu duzu dagoeneko",
    "You have been invited to an event" : "Gertaera batera gonbidatu zaituzte",
    "This event was cancelled" : "Gertaera hau bertan behera utzi da",
    "Save to" : "Gorde hona:",
    "Comment" : "Iruzkindu",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "Tentatively accept" : "Behin-behinean onartu",
    "More options" : "Aukera gehiago",
    "This event is in the past." : "Gertaera hau iraganean dago.",
    "This event was updated" : "Gertaera hau eguneratu da",
    "{attendeeName} accepted your invitation" : "{attendeeName}(e)k zure gonbidapena onartu du",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName}(e)k zure gonbidapena behin-behinean onartu du",
    "{attendeeName} declined your invitation" : "{attendeeName}(e)k zure gonbidapenari uko egin dio",
    "{attendeeName} reacted to your invitation" : "{attendeeName} gonbidapen honi buruz erreakzionatu du dagoeneko",
    "Failed to save your participation status" : "Ezin izan da gorde zure parte-hartze egoera",
    "Could not open mailbox" : "Ezin izan da postontzia ireki",
    "Loading messages …" : "Mezuak kargatzen ...",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Zure mezuak indexatzen. Honek denbora dezente har dezake postontzi handietan.",
    "To archive a message please configure an archive mailbox in account settings" : "Mezu bat artxibatzeko, konfiguratu artxiboko postontzi bat kontuaren ezarpenetan",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Ez duzu mezu hau artxibo karpetara eramateko eta/edo mezu hau uneko karpetatik ezabatzeko baimenik",
    "Choose target mailbox" : "Aukeratu helburuko postontzia",
    "No more submailboxes in here" : "Azpipostontzi gehiagorik ez hemen",
    "Choose" : "Aukeratu",
    "Important info" : "Informazio garrantzitsua",
    "Other" : "Beste bat",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mezuak automatikoki markatuko dira garrantzitsu bezala kontuan izanda zein mezurekin aritu zaren interakzioan edo zein markatu dituzun garratzitsu gisa. Hasieran garrantzia eskuz aldatu beharko duzu sistemari irakasteko, baina denborarekin hobetuko du.",
    "The sender of this message has asked to be notified when you read this message." : "Mezu honen igorleak mezu hau irakurtzean jakinaraztea eskatu du.",
    "Notify the sender" : "Jakinarazi bidaltzaileari",
    "You sent a read confirmation to the sender of this message." : "Irakurtze-berrespena bidali diozu mezu honen igorleari.",
    "Could not send mdn" : "Ezin izan da mdn bidali",
    "Reply all" : "Erantzun denei",
    "Reply" : "Erantzun",
    "Reply to sender only" : "Erantzun bakarrik igorleari",
    "Move message" : "Mugitu mezua",
    "Forward message as attachment" : "Birbidali mezua eranskin gisa",
    "View source" : "Ikusi iturburua",
    "Download thread data for debugging" : "Deskargatu hariaren datuak arazteko",
    "Message body" : "Mezuaren gorputza",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Abisua: mezu honen S/MIME sinadura egiaztatu gabe dago. Baliteke igorleak norbaiten nortasuna ordezkatzea!",
    "Import into calendar" : "Inportatu egutegira",
    "Download attachment" : "Deskargatu eranskina",
    "Save to Files" : "Gorde Fitxategiak-en",
    "Unnamed" : "Izen gabekoa",
    "Embedded message" : "Kapsulatutako mezua",
    "Next week – {timeLocale}" : "Hurrengo astea – {timeLocale}",
    "Choose a folder to store the attachment in" : "Aukeratu karpeta bat eranskina gordetzeko",
    "calendar imported" : "egutegia inportatuta",
    "View fewer attachments" : "Ikusi eranskin gutxiago",
    "Save all to Files" : "Gorde dena Fitxategiak-en",
    "Download Zip" : "Deskargatu Zip",
    "Choose a folder to store the attachments in" : "Aukeratu karpeta bat erantsitako fitxategiak gordetzeko",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Ikusi eranskin {count} gehiago","Ikusi {count} eranskin gehiago"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : " \nMezu hau PGP bidez enkriptatu da. Instalatu Mailvelope desenkriptatzeko.",
    "The images have been blocked to protect your privacy." : "Irudiak blokeatu dira zure pribatutasuna babesteko.",
    "Show images" : "Erakutsi irudiak",
    "Show images temporarily" : "Erakutsi irudiak aldi baterako",
    "Always show images from {sender}" : "Erakutsi beti {sender} erabiltzailearen irudiak",
    "Always show images from {domain}" : "Erakutsi beti {domain} domeinuko irudiak",
    "Message frame" : "Mezuaren enkoadraketa",
    "Quoted text" : "Aipatutako testua",
    "Move" : "Mugitu",
    "Moving" : "Mugitzen",
    "Moving thread" : "Haria mugitzen",
    "Moving message" : "Mezua mugitzen",
    "Mail settings" : "Posta ezarpenak",
    "Provisioned account is disabled" : "Hornitutako kontua desgaituta dago",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Mesedez, hasi saioa pasahitz bat erabiliz kontu hau gaitzeko. Uneko saioa pasahitzik gabeko autentifikazioa erabiltzen ari da, adibidez. SSO edo WebAuthn.",
    "Quota" : "Kuota",
    "Show only subscribed mailboxes" : "Erakutsi harpidetutako postontziak soilik",
    "Add mailbox" : "Gehitu postontzia",
    "Mailbox name" : "Postontziaren izena",
    "Saving" : "Gordetzen",
    "Move up" : "Eraman gora",
    "Move down" : "Eraman behera",
    "Remove account" : "Kendu kontua",
    "Loading …" : "Kargatzen...",
    "Not supported by the server" : "Zerbitzariak ez du onartzen",
    "{usage} of {limit} used" : "{usage} / {limit} erabilita",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} kontua eta cachean gordetako posta datuak Nextcloudetik ezabatu egingo dira, baina ez zure posta hornitzailetik.",
    "Remove account {email}" : "Kendu {email} kontua ",
    "Remove {email}" : "Kendu {email}",
    "Show all subscribed mailboxes" : "Erakutsi harpidetutako postontzi guztiak",
    "Show all mailboxes" : "Erakutsi postontzi guztiak",
    "Collapse mailboxes" : "Tolestu postontziak",
    "Mark all as read" : "Markatu dena irakurrita bezala",
    "Mark all messages of this mailbox as read" : "Markatu postontzi honetako mezu guztiak irakurrita bezala",
    "Add submailbox" : "Gehitu azpipostontzia",
    "Edit name" : "Editatu izena",
    "Move mailbox" : "Mugitu postontzia",
    "Clear cache" : "Garbitu cachea",
    "Clear locally cached data, in case there are issues with synchronization." : "Ezabatu lokalean katxeatutako datuak, sinkronizaziorik arazorik badagoen.",
    "Subscribed" : "Harpidetua",
    "Sync in background" : "Sinkronizatu atzealdean",
    "Clear mailbox" : "Garbitu postontzia",
    "Delete mailbox" : "Ezabatu postontzia",
    "All messages in mailbox will be deleted." : "Postontziko mezu guztiak ezabatuko dira.",
    "Clear mailbox {name}" : "Garbitu {name} postontzia",
    "The mailbox and all messages in it will be deleted." : "Postontzia eta bertan dauden mezu guztiak ezabatuko dira.",
    "Delete mailbox {name}" : "Ezabatu {name} postontzia",
    "An error occurred, unable to rename the mailbox." : "Akatsen bat gertatu da, ezin izan da postontzia berrizendatu.",
    "_{total} message_::_{total} messages_" : ["Mezu {total}","{total} mezu"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} irakurri gabe {total} -etik","{unread} irakurri gabe {total} -etik"],
    "Outbox" : "Irteera-postontzia",
    "New message" : "Mezu berria",
    "Refresh" : "Freskatu",
    "Error sending your message" : "Errorea zure mezua bidaltzerakoan",
    "Retry" : "Saiatu berriro",
    "Uploading attachments …" : "Fitxategi erantsiak igotzen...",
    "Sending …" : "Bidaltzen...",
    "Warning sending your message" : "Abisua zure mezua bidaltzerakoan",
    "Send anyway" : "Bidali nolanahi ere",
    "Minimize composer" : "minimizatu egilea",
    "Edit message" : "Editatu mezua",
    "Draft" : "Zirriborroa",
    "Message saved" : "Mezua gordeta",
    "Failed to save message" : "Mezua gordetzeak huts egin du",
    "Failed to save draft" : "Zirriborroa gordetzeak huts egin du",
    "attachment" : "eranskina",
    "attached" : "erantsita",
    "No sent mailbox configured. Please pick one in the account settings." : "Ez dago bidalitakoen postontzirik konfiguratuta. Aukeratu baten bat kontuaren ezarpenetan, mesedez.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "To eta / edo Cc-n hartzaile askori bidaltzen saiatzen ari zara. Hartzaileen helbideak ezkutatzeko Bcc erabili dezakezu.",
    "You mentioned an attachment. Did you forget to add it?" : "Eranskin bat aipatu duzu. Gehitzea ahaztu al zaizu?",
    "Message discarded" : "Mezua bertan behera utzi da",
    "Could not discard message" : "Ezin izan da mezua baztertu",
    "Welcome to {cloudName} Mail" : "Ongi etorri {cloudName} postara",
    "Autoresponder off" : "Autoerantzulea itzalita",
    "Autoresponder on" : "Autoerantzulea piztuta",
    "First day" : "Lehen eguna",
    "Last day (optional)" : "Azken eguna (aukerazkoa)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} erantzuten ari zaren mezuaren gaiarekin ordezkatuko da",
    "Message" : "Mezua",
    "Oh Snap!" : "Hara!",
    "Save autoresponder" : "Gorde autoerantzulea",
    "Could not open outbox" : "Ezin izan da irteera-postontzia ireki",
    "Pending or not sent messages will show up here" : "Bidali gabe dauden edo bidali gabeko mezuak hemen agertuko dira",
    "Delete" : "Ezabatu",
    "Message could not be sent" : "Ezin izan da mezua bidali",
    "Message deleted" : "Mezua ezabatu da",
    "Contacts with this address" : "Kontaktuak helbidearekin",
    "Add to Contact" : "Gehitun kontaktuetara",
    "New Contact" : "Kontaktu berria",
    "Copy to clipboard" : "Kopiatu arbelera",
    "Contact name …" : "Kontaktu izena ...",
    "Add" : "Gehitu",
    "Copied email address to clipboard" : "e-posta helbidea arbelera kopiatu da",
    "Could not copy email address to clipboard" : "Ezin izan da e-posta helbidea arbelera kopiatu",
    "Search in mailbox" : "Bilatu postontzian",
    "Close" : "Itxi",
    "Search parameters" : "Bilaketa parametroak",
    "Body" : "Gorputza",
    "Pick a start date" : "Aukeratu hasiera-data",
    "Pick an end date" : "Aukeratu amaiera-data",
    "Select senders" : "Hautatu bidaltzaileak",
    "Select recipients" : "Hautatu hartzaileak",
    "Select CC recipients" : "Hautatu CC hartzaileak",
    "Select BCC recipients" : "Hautatu BCC hartzaileak",
    "Tags" : "Etiketak",
    "Select tags" : "Hautatu etiketak",
    "Marked as" : "Honela markatuta:",
    "Has attachments" : "Eranskinak ditu",
    "Clear" : "Garbitu",
    "Search" : "Bilatu",
    "Date" : "Data",
    "Disabled" : "Desgaituta",
    "Enabled" : "Gaituta",
    "Sieve Host" : "Sieve ostalaria",
    "Sieve Security" : "Sieve segurtasuna",
    "Sieve Port" : "Sieve ataka",
    "Sieve Credentials" : "Sieve kredentzialak",
    "IMAP Credentials" : "IMAP kredentzialak",
    "Custom" : "Pertsonalizatua",
    "Sieve User" : "Sieve erabiltzailea",
    "Sieve Password" : "Sieve pasahitza",
    "Save sieve settings" : "Gorde sieve ezarpenak",
    "Save sieve script" : "Gorde sieve scripta",
    "The syntax seems to be incorrect:" : "Sintaxia baliogabea dirudi:",
    "This weekend – {timeLocale}" : "Hurrengo asteburua – {timeLocale}",
    "Signature …" : "Sinadura...",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Zure sinadurak 2MB baino gehiago ditu. Honek editorearen errendimendua gutxitu dezake.",
    "Save signature" : "Gorde sinadura",
    "Place signature above quoted text" : "Jarri sinadura aipatutako testuaren gainean",
    "Edit name or color" : "Editatu izena edo kolorea",
    "Delete tag" : "Ezabatu etiketa",
    "Saving new tag name …" : "Etiketa-izen berria gordetzen ...",
    "Set tag" : "Ezarri etiketa",
    "Unset tag" : "Ezarri gabeko etiketa",
    "An error occurred, unable to rename the tag." : "Errore bat gertatu da, ezin izan zaio etiketa aldatu.",
    "Add default tags" : "Gehitu etiketa lehenetsiak",
    "Add tag" : "Gehitu etiketa",
    "Saving tag …" : "Etiketa gordetzen",
    "Tag name is a hidden system tag" : "Etiketaren izena ezkutatutako sistema-etiketa da",
    "Tag already exists" : "Etiketa dagoeneko existitzen da",
    "An error occurred, unable to create the tag." : "Errore bat gertatu da, ezin da etiketa sortu.",
    "Select calendar" : "Hautatu egutegia",
    "No calendars with task list support" : "Ez dago eginkizun-zerrendarik onartzen duen egutegirik",
    "Task created" : "Eginkizuna sortuta",
    "Could not create task" : "Ezin izan da eginkizuna sortu",
    "Loading thread" : "Haria kargatzen",
    "Not found" : "Ez da aurkitu",
    "Summarizing thread failed." : "Haria laburbiltzeak huts egin du.",
    "Could not load your message thread" : "Ezin izan da zure mezuen haria kargatu",
    "The thread doesn't exist or has been deleted" : "Haria ez da existitzen edo ezabatu egin da",
    "Unsubscribe" : "Harpidetza kendu",
    "Mark as unfavorite" : "Markatu ez gogoko gisa",
    "Mark as favorite" : "Markatu gogoko gisa",
    "Mark as unread" : "Markatu irakurri gabeko gisa",
    "Mark as read" : "Markatu irakurritako gisa",
    "Archive message" : "Artxibatu mezua",
    "Delete message" : "Mezua ezabatzen",
    "Message source" : "Mezuaren iturburua",
    "Unsubscribe via link" : "Harpidetza kendu esteka bidez",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Harpidetza kentzeak {sender} posta-zerrendako mezu guztiak geldituko ditu",
    "Send unsubscribe email" : "Bidali harpidetza kentzeko mezu elektronikoa",
    "Unsubscribe via email" : "Harpidetza kendu mezu elektroniko bidez",
    "Encrypted & verified " : "Enkriptatuta eta egiaztatua",
    "Signature verified" : "Sinadura egiaztatua",
    "Signature unverified " : "Sinadura egiaztatu gabe",
    "This message was encrypted by the sender before it was sent." : "Mezu hau igorleak enkriptatu zuen bidali aurretik.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Mezu honek S/MIME sinadura digital egiaztatua dauka. Mezua ez da aldatu bidali zenetik.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Mezu honek egiaztatu gabeko S/MIME sinadura digital bat dauka. Baliteke mezua bidali zenetik aldatu izana edo sinatzailearen ziurtagiria fidagarria ez izatea.",
    "Unsubscribe request sent" : "Harpidetza kentze eskaera bidalita",
    "Could not unsubscribe from mailing list" : "Ezin izan da posta-zerrendako harpidetza kendu",
    "Go to latest message" : "Joan azken mezura",
    "Go to newest message" : "Joan mezu berrienera",
    "Thread Summary" : "Hariaren laburpena",
    "{name} Assistant" : "{name} laguntzailea",
    "Remove" : "Kendu",
    "No senders are trusted at the moment." : "Une honetan ez da igorle fidagarririk.",
    "Could not remove trusted sender {sender}" : "Ezin izan da {sender} igorle fidagarria kendu",
    "individual" : "bakarkakoa",
    "domain" : "domeinua",
    "(organizer)" : "(antolatzailea)",
    "Untitled event" : "Izenik gabeko gertaera",
    "Import into {calendar}" : "Inportatu {calendar} egutegira",
    "Event imported into {calendar}" : "Gertaera inportatu da {calendar} egutegira",
    "Airplane" : "Hegazkina",
    "Reservation {id}" : "Erreserba {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} hegaldia {depAirport} aireportutik {arrAirport} aireportura",
    "Train" : "Trena",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} trena {depStation} geltokitik {arrStation} geltokira",
    "Train from {depStation} to {arrStation}" : "Trena {depStation} geltokitik {arrStation} geltokira",
    "Mail app" : "Posta elektroniko aplikazioa",
    "The mail app allows users to read mails on their IMAP accounts." : "Posta elektroniko aplikazio honek aukera ematen die erabiltzaileei IMAP kontuetako mezuak irakurtzeko.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Hemen instantzia osoko ezarpenak aurkitu ditzakezu. Erabiltzailearen ezarpen espezifikoak aplikazioan bertan daude (beheko ezkerreko izkinan).",
    "Account provisioning" : "Kontu horniketa",
    "A provisioning configuration will provision all accounts with a matching email address." : "Hornidura konfigurazio batek kontu guztiak hornituko ditu helbide elektronikoarekin.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Hornitze domeinuaren eremuan komodina (*)  erabilita erabiltzaile guztiei aplikatuko zaien konfigurazioa sortuko da, beste konfigurazio batekin bat ez datozenean.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Hornidura mekanismoak domeinu konfigurazio zehatzak lehenetsiko ditu komodin-domeinuaren konfigurazioaren aurrean.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Erabiltzailea dagoeneko beste konfigurazio batekin hornitu ondoren bat datorren konfigurazio berri bat aurkitzen bada, konfigurazio berriak izango du lehentasuna eta erabiltzaileari berriro hornituko zaio konfigurazioarekin.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Domeinu bakoitzeko konfigurazio bakarra egon daiteke eta komodin-domeinuaren konfigurazio bakarra.",
    "These settings can be used in conjunction with each other." : "Ezarpen hauek beste batzuekin batera erabili daitezke.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Bakarrik nahi baduzu erabiltzaile guztientzako domeinua hornitzea, erabili komodina (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ezarpen honek zentzua dauka zure Nextcloud eta mail zerbitzariek erabiltzaileen atzealde berdina erabiltzen badute zure erakundean.",
    "Provisioning Configurations" : "Horniketa konfigurazioak",
    "Add new config" : "Gehitu ezarpen berria",
    "Provision all accounts" : "Hornitu kontu guztiak",
    "Allow additional mail accounts" : "Onartu e-mail kontu gehigarriak",
    "Allow additional Mail accounts from User Settings" : "Onartu posta kontu gehigarriak erabiltzaile ezarpenetatik",
    "Enable thread summary" : "Gaitu harien laburbiltzea",
    "Enable thread summaries" : "Gaitu harien laburbiltzea",
    "Anti Spam Service" : "Anti spam zerbitzua",
    "You can set up an anti spam service email address here." : "Hemen spamaren aurkako zerbitzuaren helbide elektronikoa konfigura dezakezu.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Spam gisa markatutako edozein mezu elektroniko spamaren aurkako zerbitzura bidaliko da.",
    "Gmail integration" : "Gmail integrazioa",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail-ek erabiltzaileei euren posta elektronikora sartzeko baimena ematen die IMAP bidez. Segurtasun arrazoiengatik sarbide hori soilik da posible OAuth 2.0 konexio batekin edo bi faktoreko autentifikazioa eta aplikazioen pasahitzak erabiltzen diren Google kontuekin.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "\"Web aplikazio\" baterako bezero ID berri bat erregistratu behar duzu Google Cloud kontsolan. Gehitu {url} URLa baimendutako birbideratze URI gisa.",
    "Microsoft integration" : "Microsoft integrazioa",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft-ek erabiltzaileei euren posta elektronikora sartzeko baimena ematen die IMAP bidez. Segurtasun arrazoiengatik, sarbide hori OAuth 2.0 konexio batekin bakarrik da posible.",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Aplikazio berri bat erregistratu behar duzu Microsoft Azure Active Directory atarian. Gehitu {url} URLa birbideratzeko URI gisa.",
    "Successfully updated config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa behar bezala eguneratu da",
    "Error saving config" : "Errorea konfigurazioa gordetzean",
    "Saved config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa gorde da",
    "Could not save provisioning setting" : "Ezin izan da hornidura ezarpena gorde",
    "There was an error when provisioning accounts." : "Errore bat gertatu da kontuak hornitzean.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\"-ren kontuak behar bezala ezabatu dira.",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errorea gertatu da \"{domain}\"-ren kontuak ezabatzean.",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} kontua behar bezala hornitu da.","{count} kontuak behar bezala hornitu dira."],
    "Anti Spam" : "Spamaren aurkakoa",
    "Add the email address of your anti spam report service here." : "Gehitu hemen spamaren aurkako jakinarazpen-zerbitzuaren helbide elektronikoa .",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Ezarpen hau erabiltzean, jakinarazpen-mezu elektroniko bat bidaliko zaio SPAM jakinarazpen-zerbitzariari erabiltzaile batek \"Markatu spam gisa\"-n klik egiten duenean.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Jatorrizko mezua \"message/rfc822\" eranskin gisa erantsiko da.",
    "\"Mark as Spam\" Email Address" : "\"Markatu Spama gisa\" helbide elektronikoa",
    "\"Mark Not Junk\" Email Address" : "\"Markatu mezu ez-baztergarri gisa\" helbide elektronikoa",
    "Reset" : "Berrezarri",
    "Successfully set up anti spam email addresses" : "Konfiguratu spamaren aurkako helbide elektronikoak",
    "Error saving anti spam email addresses" : "Errorea spamaren aurkako helbide elektronikoak gordetzean",
    "Successfully deleted anti spam reporting email" : "Spamaren aurkako jakinarazpen mezu elektronikoa behar bezala ezabatu da",
    "Error deleting anti spam reporting email" : "Errorea spamaren aurkako jakinarazpen mezu elektronikoa ezabatzean",
    "Client ID" : "Bezeroaren IDa",
    "Client secret" : "Bezeroaren sekretua",
    "Unlink" : "Deskonektatu",
    "Google integration configured" : "Google integrazioa konfiguratu da",
    "Could not configure Google integration" : "Ezin izan da Google integrazioa konfiguratu",
    "Google integration unlinked" : "Desestekatu da Google-ren integrazioa",
    "Could not unlink Google integration" : "Ezin izan da desestekatu Google integrazioa",
    "Tenant ID (optional)" : "Maizterraren ID (aukerakoa)",
    "Microsoft integration configured" : "Microsoft integrazioa konfiguratu da",
    "Could not configure Microsoft integration" : "Ezin izan da Microsoft integrazioa konfiguratu",
    "Microsoft integration unlinked" : "Microsoft integrazioa desestekatu da",
    "Could not unlink Microsoft integration" : "Ezin izan da desestekatu Microsoft integrazioa",
    "Domain Match: {provisioningDomain}" : "Bat datorren domeinua: {provisioningDomain}",
    "Email: {email}" : "Posta helbidea: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} hemen: {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} hemen: {host}:{port} ({ssl} encryption)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} {host}-en: {port} ({ssl} enkriptatzea)",
    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\"-ren konfigurazioa",
    "General" : "Orokorra",
    "Provisioning domain" : "Domeinua hornitzen",
    "Email address template" : "E-postaren txantiloia",
    "IMAP" : "IMAP",
    "User" : "Erabiltzailea",
    "Host" : "Ostalaria",
    "Port" : "Ataka",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Gaitu sieve integrazioa",
    "LDAP aliases integration" : "LDAP aliasen integrazioa",
    "Enable LDAP aliases integration" : "Gaitu LDAP ezizenen integrazioa",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP aliasen integrazioak konfiguratutako LDAP direktorioko atributu bat irakurtzen du posta elektroniko aliasak hornitzeko.",
    "LDAP attribute for aliases" : "Aliasentzako LDAP atributua",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Balio anitzeko atributu bat posta elektroniko aliasak hornitzeko. Balio bakoitzerako alias bat sortzen da. LDAP direktorioan ez dauden Nextcloud-en dauden aliasak ezabatzen dira.",
    "Save Config" : "Gorde konfigurazioa",
    "Unprovision & Delete Config" : "Ez hornitu eta ezabatu konfigurazioa",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% eta%EMAIL% erabiltzailearen UID eta e-postarekin ordeztuko dira",
    "With the settings above, the app will create account settings in the following way:" : "Goiko ezarpenekin, aplikazioak honako ezarpenak dituzten kontuak sortuko ditu:",
    "S/MIME certificates" : "S/MIME ziurtagiriak",
    "Certificate name" : "Ziurtagiriaren izena",
    "E-mail address" : "E-mail helbidea",
    "Valid until" : "Data hau arte baliogarria",
    "Delete certificate" : "Ezabatu ziurtagiria",
    "No certificate imported yet" : "Oraindik ez da inportatu ziurtagiririk",
    "Import certificate" : "Inportatu ziurtagiria",
    "Import S/MIME certificate" : "Inportatu S/MIME ziurtagiria",
    "PKCS #12 Certificate" : "PKCS #12 Ziurtagiria",
    "PEM Certificate" : "PEM Ziurtagiria",
    "Certificate" : "Ziurtagiria",
    "Private key (optional)" : "Gako pribatua (aukerakoa)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Gako pribatua beharrezkoa da  soilik ziurtagiri hau erabiliz sinatutako eta enkriptatutako mezu elektronikoak bidaltzeko asmoa baduzu .",
    "Submit" : "Bidali",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Emandako PKCS #12 ziurtagiriak gutxienez izan behar ditu ziurtagiri bat eta gako pribatu bat zehazki.",
    "Failed to import the certificate. Please check the password." : "Ezin izan da ziurtagiria inportatu. Mesedez, egiaztatu pasahitza.",
    "Certificate imported successfully" : "Ziurtagiria ongi inportatu da",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Ezin izan da ziurtagiria inportatu. Mesedez, ziurtatu gako pribatua ziurtagiriarekin bat datorrela eta ez dagoela pasaesaldi batek babestuta.",
    "Failed to import the certificate" : "Ezin izan da ziurtagiria inportatu",
    "Keyboard shortcut" : "Teklatuko lasterbidea",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "Speed up your Mail experience with these quick shortcuts." : "Zure Mail erabilpena azkartu lasterbide azkar hauekin",
    "Compose new message" : "Idatzi mezu berria",
    "Newer message" : "Mezu berriagoa",
    "Older message" : "Mezu zaharragoa",
    "Toggle star" : "Txandakatu izarra",
    "Toggle unread" : "Txandakatu irakurri gabea",
    "Archive" : "Artxibatu",
    "Account connected" : "Kontua konektatuta",
    "You can close this window" : "Leiho hau itxi dezakezu",
    "Connect your mail account" : "Konektatu zure posta kontua",
    "To add a mail account, please contact your administrator." : "E-mail kontua gehitzeko, kontaktatu zure administratzailearekin, mesedez.",
    "Tomorrow – {timeLocale}" : "Bihar – {timeLocale}",
    "Later today – {timeLocale}" : "Beranduago gaur – {timeLocale}",
    "Itinerary for {type} is not supported yet" : "{type} motarentzako ibilbidea ez da onartzen oraindik",
    "All" : "Denak",
    "Drafts" : "Zirriborroak",
    "Favorites" : "Gogokoak",
    "Priority inbox" : "Lehentasuneko sarrera",
    "All inboxes" : "Postontzi guztiak",
    "Inbox" : "Sarrera-ontzia",
    "Junk" : "Zaborra",
    "Sent" : "Bidalia",
    "Trash" : "Zakarrontzia",
    "Connect OAUTH2 account" : "Konektatu OAUTH2 kontua",
    "Error while sharing file" : "Errorea fitxategia partekatzean",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["Mezu berri %n \njaso duzu {from} helbidetik","%n mezu berri \njaso dituzu {from} helbidetik"],
    "Nextcloud Mail" : "Nextcloud Posta",
    "Discard changes" : "Baztertu aldaketak",
    "Discard unsaved changes" : "Baztertu gorde gabeko aldaketak",
    "Keep editing message" : "Jarraitu mezua editatzen",
    "Attachments were not copied. Please add them manually." : "Ezin izan dira atxikitakoak kopiatu. Gehitu itzazu eskuz, mesedez.",
    "Message sent" : "Mezua bidalita",
    "Could not send message" : "Ezin izan da mezua bidali",
    "Could not load {tag}{name}{endtag}" : "Ezin izan da {tag}{name}{endtag} kargatu",
    "There was a problem loading {tag}{name}{endtag}" : "Arazo bat egon da {tag}{name}{endtag} kargatzerakoan",
    "Could not load your message" : "Ezin izan da zure mezua kargatu",
    "Could not load the desired message" : "Ezin izan da kargatu nahi zen mezu hori",
    "Could not load the message" : "Ezin izan da mezua kargatu",
    "Error loading message" : "Errorea mezua kargatzerakoan",
    "Forwarding to %s" : "%s helbidera birbidaltzen",
    "Click here if you are not automatically redirected within the next few seconds." : "Egin klik hemen hurrengo segundoetan automatikoki birbideratzen ez bada.",
    "Redirect" : "Birbideratu",
    "The link leads to %s" : "Estekak hona bideratzen du: %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
    "Continue to %s" : "Jarraitu hona: %s"
},
"nplurals=2; plural=(n != 1);");
